package com.ruoyi.interfaces.service;

import java.util.List;
import com.ruoyi.interfaces.domain.MdDataField;

/**
 * 数据集字段Service接口
 * 
 * @author ruoyi
 * @date 2025-07-30
 */
public interface IMdDataFieldService 
{
    /**
     * 查询数据集字段
     * 
     * @param dsCode 数据集字段主键
     * @return 数据集字段
     */
    public List<MdDataField> selectMdDataFieldByDsCode(String dsCode);

    /**
     * 查询数据集字段列表
     * 
     * @param mdDataField 数据集字段
     * @return 数据集字段集合
     */
    public List<MdDataField> selectMdDataFieldList(MdDataField mdDataField);

    /**
     * 新增数据集字段
     * 
     * @param mdDataField 数据集字段
     * @return 结果
     */
    public int insertMdDataField(MdDataField mdDataField);

    /**
     * 修改数据集字段
     * 
     * @param mdDataField 数据集字段
     * @return 结果
     */
    public int updateMdDataField(MdDataField mdDataField);

    /**
     * 批量删除数据集字段
     * 
     * @param dsCodes 需要删除的数据集字段主键集合
     * @return 结果
     */
    public int deleteMdDataFieldByDsCodes(String[] dsCodes);

    /**
     * 删除数据集字段信息
     * 
     * @param dsCode 数据集字段主键
     * @return 结果
     */
    public int deleteMdDataFieldByDsCode(String dsCode);

    int deleteMdDataFieldOne(MdDataField mdDataField);
}
